@@ -1,3 +1,5 @@
+import json
+
 from httpx import AsyncClient
 from thingy import NamesMixin, Thingy, classproperty
 
@@ -16,9 +18,10 @@ class Cursor:
         self.params["cursor"] = self.index
 
         async with AsyncClient(base_url=self.cls.base_url) as client:
+            params = {key: json.dumps(value) for key, value in self.params.items()}
             response = await client.get(
                 f"/api/1.1/obj/{self.cls.typename}",
-                params=self.params,
+                params=params,
                 headers=self.cls._headers,
             )
             response.raise_for_status()
@@ -58,6 +61,11 @@ class Cursor:
             self.cached.append(bubble_object)
         return bubble_object
 
+    async def count(self):
+        if not self.page:
+            self.page = await self._get_page()
+        return self.page["cursor"] + self.page["count"] + self.page["remaining"]
+
     def rewind(self):
         self.index = 0
 
@@ -75,9 +83,18 @@ class BubbleThing(NamesMixin, Thingy):
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
-        self.__dict__ = {
-            key.replace(" ", "_").lower(): value for key, value in self.__dict__.items()
-        }
+
+        __dict__ = {}
+        includes = []
+
+        for key, value in self.__dict__.items():
+            alias = key.replace(" ", "_").lower()
+            __dict__[alias] = value
+            if key not in ("Modified Date", "Created Date", "Created By", "_id"):
+                includes.append((alias, key))
+
+        self.__dict__ = __dict__
+        self.add_view("bubble", include=includes)
 
     @classmethod
     def configure(cls, base_url, token, headers=None):
@@ -130,6 +147,11 @@ class BubbleThing(NamesMixin, Thingy):
             return await cls._get_by_id(id, **params)
         return await cls._get_first(**params)
 
+    @classmethod
+    async def count(cls, **params):
+        params["limit"] = 1
+        return await cls.get(**params).count()
+
     async def _join_by_cursor(self, key, cursor):
         other_id_or_ids = getattr(self, key)
         if not other_id_or_ids:
@@ -181,6 +203,27 @@ class BubbleThing(NamesMixin, Thingy):
         else:
             return await self._join_by_cls(key, cursor_or_other_cls, **params)
 
+    async def save(self, **params):
+        async with AsyncClient(base_url=self.__class__._base_url) as client:
+            if self._id:
+                response = await client.put(
+                    f"/api/1.1/obj/{self.__class__.typename}/{self._id}",
+                    params=params,
+                    headers=self.__class__._headers,
+                    json=self.view("bubble"),
+                )
+                response.raise_for_status()
+            else:
+                response = await client.post(
+                    f"/api/1.1/obj/{self.__class__.typename}",
+                    params=params,
+                    headers=self.__class__._headers,
+                    json=self.view("bubble"),
+                )
+                response.raise_for_status()
+                self._id = response.json()["id"]
+
+        return self
 
 configure = BubbleThing.configure
 
